==> electron-re-1.2.0.tgz: package/lib/index.js <==
"use strict";

var _require = require('./libs/utils'),
    isRenderer = _require.isRenderer,
    isMain = _require.isMain,
    isForkedChild = _require.isForkedChild;

var _require2 = require('./tasks/app.init'),
    listenerForNewWindow = _require2.listenerForNewWindow,
    registryProtocolForService = _require2.registryProtocolForService,
    polyfillRemote = _require2.polyfillRemote;

exports.ChildProcessPool = require('./libs/ChildProcessPool');
exports.LoadBalancer = require('./libs/LoadBalancer');
exports.ProcessHost = require('./libs/ProcessHost.class');
exports.ProcessLifeCycle = require('./libs/ProcessLifeCycle.class');
/* -------------- renderer process -------------- */

if (isRenderer) {
  exports.MessageChannel = require('./libs/MessageChannel.class');
}
/* -------------- main process -------------- */


if (isMain && !isForkedChild) {
  var _require3 = require('electron'),
      BrowserWindow = _require3.BrowserWindow,
      app = _require3.app;

  exports.BrowserService = require('./libs/BrowserService.class');
  exports.MessageChannel = require('./libs/MessageChannel.class');
  exports.ProcessManager = require('./libs/ProcessManager');
  /* new service listen */

  exports.MessageChannel.event.on('registry', function (_ref) {
    var pid = _ref.pid,
        id = _ref.id;
    var win = BrowserWindow.fromId(id);
    if (win && pid) exports.ProcessManager.listen(pid, 'service', win.webContents.getURL());
  });
  exports.MessageChannel.event.on('unregistry', function (_ref2) {
    var pid = _ref2.pid;
    exports.ProcessManager.unlisten(pid);
  });
  /* new renderer-window listen */

  listenerForNewWindow(app, exports);
  /* registry protocol */

  registryProtocolForService(app, exports);
  /* polyfill - remote */

  polyfillRemote(app, exports);
}

==> electron-re-1.2.8.tgz: package/lib/index.js <==
"use strict";

var _require = require('./libs/utils'),
    isRenderer = _require.isRenderer,
    isMain = _require.isMain,
    isForkedChild = _require.isForkedChild;

var _require2 = require('./libs/WorkerThreadPool'),
    THREAD_TYPE = _require2.THREAD_TYPE,
    StaticThreadPool = _require2.StaticThreadPool,
    DynamicThreadPool = _require2.DynamicThreadPool;

exports.ChildProcessPool = require('./libs/ChildProcessPool');
exports.LoadBalancer = require('./libs/LoadBalancer');
exports.ProcessHost = require('./libs/ProcessHost.class');
exports.ProcessLifeCycle = require('./libs/ProcessLifeCycle.class');
exports.StaticThreadPool = StaticThreadPool;
exports.DynamicThreadPool = DynamicThreadPool;
exports.THREAD_TYPE = THREAD_TYPE;
/* -------------- renderer process -------------- */

if (isRenderer) {
  exports.MessageChannel = require('./libs/MessageChannel.class');
}
/* -------------- main process -------------- */


if (isMain && !isForkedChild) {
  var _require3 = require('electron'),
      app = _require3.app;

  var _require4 = require('./tasks/app.init'),
      registryProtocolForService = _require4.registryProtocolForService,
      polyfillRemote = _require4.polyfillRemote;

  exports.BrowserService = require('./libs/BrowserService.class');
  exports.MessageChannel = require('./libs/MessageChannel.class');
  exports.ProcessManager = require('./libs/ProcessManager');
  /* registry protocol */

  registryProtocolForService(app, exports);
  /* polyfill - remote */

  polyfillRemote(app, exports);
}
